function [fullfilename] = MSGbuildfullfilename(ncfilesset, Annee, Mois, Jour)

%MSGbuildfullfilename permet d'obtenir le chemin d'acces a un fichier
%NetCDF, de donnees de temperature de brillance par MSG, pour la date
%desiree.

%
%+
%
% =======================
% MSGbuildfullfilename.m
% =======================
%
% .. function:: MSGbuildfullfilename(ncfilesset, Annee, Mois, Jour)
%
% DESCRIPTION
% ===========
%
% - Donnees d'entrees :
%
%   * ncfilesset (en caracteres) : Type de fichier NetCDF que l'on cherche,
%     'normal' ou 'extracted'.
%   * Annee (en caracteres) : Annee (AAAA) du jour d'etude.
%   * Mois (en caracteres) : Numero du mois (MM) du jour d'etude.
%   * Jour (en caracteres) : Numero du Jour d'etude (JJ).
%
% - Donnees de sorties :
%
%   * fullfilename : Chemin d'acces au fichier pour la date desiree.
%
% Cette fonction permet d'obtenir le chemin d'acces a un fichier NetCDF,
% de donnees de temperature de brillance par MSG, pour la date desiree.
%
% EXAMPLES
% ========
%
% Voir la 'demo'.
%
% SEE ALSO
% ========
%
% :ref:`data_msg`
%
% :ref:`varamma_startup.m`
%
% :func:`MSGread`
%
% TODO
% ====
%
% add demo extracted
%
% test if file exists and handling error
%
% EVOLUTIONS
% ==========
%
% $Id$
%
% $URL$
%
% - fplod 20110801T134631Z aedon.locean-ipsl.upmc.fr (Darwin)
%
%   * date is a reserved word : replaced by date_file
%
% - jaclod 2011-07-26
%
%   * Revision de la documentation et des commentaires.
%
% - jaclod 2011-07-21
%
%   * Adaptation pour les fichiers 'extracted'.
%
% - jaclod 2011-07-13
%
%   * Creation
%
%-

% Appel de la variable global 'PROJECT_ID' (Il faut auparavant avoir
% execute 'varamma_startup').
global PROJECT_ID

% Creation d'une variable comportant la date nous permettant de
% selectionner le fichier en question.
date_file = ([Annee '-' Mois '-' Jour]);

% Le repertoire ou se trouve le fichier, ainsi que son nom, different selon
% qu'il soit 'normal' (fichier original) ou 'extracted' (fichier avec
% extraction des donnees spatiales).
switch ncfilesset

    case 'normal'

        % Repertoire contenant le fichier souhaite.
        repertoire = [ PROJECT_ID 'MSG/' Annee '/' Mois '/' ];

        % Creation du chemin complet.
        fullfilename = [repertoire 'msg-tb108_' date_file '_15min.nc'];

case 'extracted'

        % Repertoire contenant le fichier souhaite.
        repertoire = [ PROJECT_ID 'MSG/extracted/' Annee '/' Mois '/' ];

        % Creation du chemin complet.
        fullfilename = [repertoire 'extracted-msg-tb108_' date_file '_15min.nc'];

    otherwise

        error('La variable ncfilesset doit etre ''normal'' ou ''extracted''.');

end

end

%!demo
%! varamma_startup;
%! more off;
%! Annee = '2006';
%! Mois = '07';
%! Jour = '28';
%! ncfilesset = 'normal';
%! [fullfilename] = MSGbuildfullfilename(ncfilesset, Annee, Mois, Jour)
