function [result] = box5x5serietemp(ij_concat, time_concat)

%box5x5serietemp permet de faire des series temporelles de l'evolution
%moyenne d'une variable sur des zones de 5 sur 5 degres dans la zone 
%d'etude 0-20W et 0-20N a la resolution d'EPSAT (200*200).

%
%+
%
% ==================
% box5x5serietemp.m
% ==================
%
% .. function:: box5x5serietemp(ij_concat, time_concat)
%
% DESCRIPTION
% ===========
%
% - Donnees d'entrees :
%
%   * ij_concat : Donnees concatenees dans une matrice 3D de dimensions
%     temps, longitudes, latitudes.
%   * time_concat : Variable temporelle de la matrice en jour julien.
%
% EXAMPLES
% ========
%
% Voir la 'demo'.
%
% SEE ALSO
% ========
%
% :func:`cumulEPSAT_concat` 
% :func:`intensityMSG_concat` 
% :func:`missingdaytonan` 
% :func:`serietemp` 
%
% TODO
% ====
%
% EVOLUTIONS
% ==========
%
% $Id$
%
% $URL$
%
% - fplod 20110804T125129Z cratos (Linux)
%
%   * add result
%
% - jaclod 2011-07-29
%
%   * Revision finale du stage du mois de juillet 2011.
%
% - jaclod 2011-07-27
%
%   * Ajout de la documentation, des commentaires et de la demonstration.
%
% - jaclod 2011-07-26
%
%   * Creation.
%
%-

result=-1;

%%%%%%%%%%%%%%%%%
% Initialisation
%%%%%%%%%%%%%%%%%

% Creation d'une matrice de meme dimension temporelle que la matrice
% d'entree et une dimension spatiale de 4 sur 4 pour nos 16 zones de 5 sur
% 5 degres.
box5x5_concat = zeros(size(ij_concat,1),4,4);

%%%%%%%%%%%%%%%%%


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Moyennage pour chaque zone
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% Boucle sur chaque pas de temps, chaque jour, et chaque pas de variation
% spatiale.
for timestep = 1:size(ij_concat,1);
    
    for dlon = 1:4;
       
        for dlat = 1:4;
           
            % Recuperation de l'information moyenne sur cette zone et ce
            % jour.
            box5x5_concat(timestep,dlon,dlat) = mean(mean(ij_concat(timestep,1+(dlon-1)*50:dlon*50,1+(dlat-1)*50:dlat*50)));
            
        end
        
    end

end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


%%%%%%%%%%%%%%%%%%%%%
% Series temporelles
%%%%%%%%%%%%%%%%%%%%%

% Ouverture d'une figure blanche en plein ecran.
h=figure;
set(h,'color','w','units','normalized','position',[0 0 1 1]);

% Boucle sur les zones.
for dlon = 1:4;
    
   for dlat = 1:4;
       
       % On se place dans une petite parcelle de la figure tout en gardant
       % l'emplacement respectif par rapport aux autres zones.
       subplot(4,4,(4-dlat)*4+dlon);
       
       % Recuperation des donnees de la zone correspondante.
       data = squeeze(box5x5_concat(:,dlon,dlat));
       
       % Tracage de la serie temporelle.
       result=serietemp(data, time_concat, 'mmm dd',3, 'cumuls EPSAT (mm)');
       
       % Modifications des titres et axes pour plus de clarete.
       xlabel('');
       ylabel('');
       title([num2str((dlat-1)*5) ' a ' num2str((dlat)*5) 'N et ' num2str((5-dlon)*5) ' a ' num2str((4-dlon)*5) 'W'])
       
   end
    
end

result=0;

end

%!demo
%! varamma_startup;
%! more off;
%! [ij_cumul_concat, time_concat, Longitudes, Latitudes] = cumulEPSAT_concat('extracted', 0,0,0,0,0,0, 2006);
%! [ij_cumul_concat, time_concat] = missingdaytonan(ij_cumul_concat, time_concat);
%! result=box5x5serietemp(ij_cumul_concat, time_concat);
