function [dataextracted, dim1extracted, dim2extracted, dim3extracted] = extractedmatrixdata(data, dim1, dim2, dim3, mindim1, maxdim1, mindim2, maxdim2, mindim3, maxdim3)

%extractedmatrixdata permet d'extraire les donnees d'une matrice 3D ainsi
%que ses variables a partir des bornes choisies pour chacune d'elles.

%
%+
%
% ======================
% extractedmatrixdata.m
% ======================
%
% .. function:: extractedmatrixdata(data, dim1, dim2, dim3, mindim1, maxdim1, mindim2, maxdim2, mindim3, maxdim3)
%
% DESCRIPTION
% ===========
%
% - Donnees d'entrees :
%
%   * data : Donnees initiales de la matrice 3D (dim1, dim2, dim3).
%   * dim1 : Dimension 1 de la matrice 'data'.
%   * dim2 : Dimension 2 de la matrice 'data'.
%   * dim3 : Dimension 3 de la matrice 'data'.
%   * mindim1 : Borne inferieure pour l'extraction de la dimension 1.
%   * maxdim1 : Borne superieure pour l'extraction de la dimension 1. 
%   * mindim2 : Borne inferieure pour l'extraction de la dimension 2.
%   * maxdim2 : Borne superieure pour l'extraction de la dimension 2. 
%   * mindim3 : Borne inferieure pour l'extraction de la dimension 3.
%   * maxdim3 : Borne superieure pour l'extraction de la dimension 3. 
%
% - Donnees de sorties :
%
%   * dataextracted : Donnees extraites de la matrice 3D initiale.
%   * dim1extracted : Dimension 1 extraite de la matrice 'dataextracted'.
%   * dim2extracted : Dimension 2 extraite de la matrice 'dataextracted'.
%   * dim3extracted : Dimension 3 extraite de la matrice 'dataextracted'.
%
% Cette fonction permet d'extraire les donnees d'une matrice 3D ainsi
% que ses variables a partir des bornes choisies pour chacune d'elles.
%
% EXAMPLES
% ========
%
% Voir les demo
%
% SEE ALSO
% ========
%
% TODO
% ====
%
% make it work with demo with MSG real file
%
% Message d'erreur ou d'avertissement lorsque les bornes depassent les
% donnees. Avertir et prendre toutes les donnees ?
%
% EVOLUTIONS
% ==========
%
% $Id$
%
% $URL$
%
% - fplod 20110804T103019Z aedon.locean-ipsl.upmc.fr (Darwin)
%
%   * change school demo
%   * add demo with MSG real file normal and extracted
%
% - jaclod 2011-07-26
%
%   * Revision de la documentation et des commentaires.
%
% - jaclod 2011-07-20
%
%   * Ajout de la documentation et modifications des commentaires.
%
% - jaclod 2011-07-12
%
%   * Creation.
%
%-

% On cherche les indices extremes dans les matrices bornant les donnees
% souhaitees. Pour cela on prend le premier indice tel que a partir
% de celui-ci on depasse la limite inferieure et le dernier indice tel 
% qu'on est sous la limite superieure.
indexmin1 = find(dim1 >= mindim1, 1, 'first');
indexmax1 = find(dim1 <= maxdim1, 1, 'last');
indexmin2 = find(dim2 >= mindim2, 1, 'first');
indexmax2 = find(dim2 <= maxdim2, 1, 'last');
indexmin3 = find(dim3 >= mindim3, 1, 'first');
indexmax3 = find(dim3 <= maxdim3, 1, 'last');

% Extraction des donnees seulement entre les indices de bornes, pour les
% differentes dimensions et pour la matrice de donnees.
dim1extracted = dim1(indexmin1:indexmax1);
dim2extracted = dim2(indexmin2:indexmax2);
dim3extracted = dim3(indexmin3:indexmax3);
dataextracted = data(indexmin1:indexmax1,indexmin2:indexmax2,indexmin3:indexmax3);

end

%!demo
%! % school example
%! % 5x10x15 3D array.  extracted 1x2x3
%! clear all
%! data = reshape(1:5 * 10 * 15,5,10,15);
%! dim1 = 1:5;
%! dim2 = 11:15;
%! dim3 = 101:115;
%! mindim1 = 1;
%! maxdim1 = 1;
%! mindim2 = 13;
%! maxdim2 = 14;
%! mindim3 = 105;
%! maxdim3 = 107;
%! [dataextracted, dim1extracted, dim2extracted, dim3extracted] = extractedmatrixdata(data, dim1, dim2, dim3, mindim1, maxdim1, mindim2, maxdim2, mindim3, maxdim3)

%!demo
%! % From real file :file:`${PROJECT_ID}MSG/msg-tb108_2006-08-01_15min.nc` ::
%! clear all
%! close all
%! varamma_startup
%! more off
%! Annee = '2006';
%! Mois = '08';
%! Jour = '01';
%! ncfilesset = 'normal';
%! [fullfilename] = MSGbuildfullfilename(ncfilesset, Annee, Mois, Jour);
%! [TbMSG, Temps, Longitudes, Latitudes] = MSGread(ncfilesset, fullfilename);
%! mindim1=min(Temps);
%! maxdim1=max(Temps);
%! lonmin = -20;
%! lonmax = -10;
%! latmin = 10;
%! latmax = 20;
%! [TbMSG_e, Temps_e, Longitudes_e, Latitudes_e] = extractedmatrixdata(TbMSG, Temps, Longitudes, Latitudes, mindim1, maxdim1, lonmin, lonmax, latmin, latmax);
%! whos

%!demo
%! % From real file :file:`${PROJECT_ID}MSG/extracted/2006/08/extracted-msg-tb108_2006-08-01_15min.nc` ::
%! clear all
%! close all
%! varamma_startup;
%! more off
%! Annee = '2006';
%! Mois = '08';
%! Jour = '01';
%! [fullfilename] = MSGbuildfullfilename('extracted', Annee, Mois, Jour);
%! [TbMSG, Temps, Longitudes, Latitudes] = MSGread('extracted', fullfilename);
%! mindim1=min(Temps);
%! maxdim1=max(Temps);
%! lonmin = -20;
%! lonmax = -10;
%! latmin = 10;
%! latmax = 20;
%! [TbMSG_e, Temps_e, Longitudes_e, Latitudes_e] = extractedmatrixdata(TbMSG, Temps, Longitudes, Latitudes, mindim1, maxdim1, lonmin, lonmax, latmin, latmax);
%! whos
