function rmix=hspe2rmix(hspe,p)

%HSPE2RMIX Calcul du rapport de melange a partir de l'humidite specifique

%+
%
% .. _hspe2rmix.m:
%
% ===========
% hspe2rmix.m
% ===========
%
% DESCRIPTION
% ===========
%
% Calcul du rapport de melange a partir de
% l'humidite specifique et la pression en utilisant :
%
%  - rmix = 0.622*e/(p-e)
%  - hspe = 0.622*e/(p-0.378*e)) avec e la pression partielle de vapeur d'eau
%
% Entrees :
%
% hspe
%    l'humidite specifique en g/kg ou kg/kg
% p
%    la pression de l'air en hPa ou Pa 
%
% Sortie :
%
% rmix
%    rapport de melange en kg/kg
%
% EXAMPLES
% ========
%
% voir :ref:`cal_hcl.m` pour exemple d'utilisation
%
% SEE ALSO
% ========
%
% TODO
% ====
%
% EVOLUTIONS
% ==========
%
% $Id: hspe2rmix.m 325 2011-08-04 15:30:01Z pinsard $
%
% $URL$
%
%-

%test si hspe est en g/kg ou kg/kg
ind_nan=find(~isnan(hspe));
if hspe(ind_nan(1))>1
  hspe=hspe/1000;
end

% Pression partielle de vapeur d'eau
e=hspe.*p./(0.622+0.378*hspe);

% Rapport de melange
rmix=hspe.*((p-0.378*e)./(p-e));

