%+
%
% .. _intensity_day.m:
%
% ===============
% intensity_day.m
% ===============
%
% DESCRIPTION
% ===========
%
% Programme d'analyse des nuages avec MSG, produisant une intensit
% journalire  la rsolution d'EPSAT.
%
% SEE ALSO
% ========
%
% TODO
% ====
%
% EVOLUTIONS
% ==========
%
% $Id$
%
% $URL$
%
%   * creation
%
%-


% clear all
% close all

%%%%%%%%%%%%%%%%%%%%%%%%%%
%
%   Conditions d'tude
%
%%%%%%%%%%%%%%%%%%%%%%%%%% 

if exist('Tb_SeuilSup','var')~=1;
    % Seuil de Tb en Kelvin (Temprature de brillance).
    Tb_SeuilSup = 239; %Ou = input(' Maximum de Tb (en Kelvin) : ');
end

if exist('Tb_LimNoyau','var')~=1;
    % Limite Noyau-Ext en Tb.
    Tb_LimNoyau = 190; %Ou = input(' Limite Noyau (en Kelvin) : ');
end

if exist('Tps_SeuilInf','var')~=1;
    % Seuil de temps en quarts d'heure.
    Tps_SeuilInf = 3; %Ou = input(' Minimum de dure (en quarts d''heure) : ');
end

% Domaine d'tude.
latmin = 10;
latmax = 20;
lonmin = -20;
lonmax = -10;


%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% Recherche des fichiers
%
%%%%%%%%%%%%%%%%%%%%%%%%%%


% Ajout du repertoire de fichiers netcdf dans les dossiers de recherche de
% Matlab.
repertoire = 'C:\Users\Jas\Desktop\Documents de Travail\S6\Stage au labo LOCEAN\Matlab\MSG\';
path(path,repertoire);

% Liste des fichiers netCDF.
ext = '*.nc';
chemin = fullfile(repertoire,ext);
liste = dir(chemin);
nbjour = numel(liste);


%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% Boucle sur les fichiers
%
%%%%%%%%%%%%%%%%%%%%%%%%%%

for num_jour = 1 : nbjour;

    % On rcupre le nom du fichier dans la liste.
    fichier = liste(num_jour).name;
    
    
    %%%%%%%%%%%%%%%%%%%%%%%%%%
    %
    % Rcupration des donnes
    %
    %%%%%%%%%%%%%%%%%%%%%%%%%%
    
    % Ouverture du fichier.
    ncid = netcdf.open(fichier, 'NC_NOWRITE');
    
    % Rcupration des variables.
    Temps = netcdf.getVar(ncid,3);
    Longitudes = netcdf.getVar(ncid,1);
    Latitudes = netcdf.getVar(ncid,2);
    
    % On cherche la premiere et le nombre de latitude/longitude  prendre
    % en compte d'aprs notre domaine d'tude prcdemment dfinit.
    startlat = find(Latitudes>=latmin, 1 );
    countlat = find(Latitudes<=latmax, 1, 'last' ) - startlat +1;
    startlon = find(Longitudes>=lonmin, 1 );
    countlon = find(Longitudes<=lonmax, 1, 'last' ) - startlon +1;
    
    % Restriction des donnes de lat/long  notre domaine.
    Latitudes = Latitudes(Latitudes>=latmin & Latitudes<=latmax);
    Longitudes = Longitudes(Longitudes>=lonmin & Longitudes<=lonmax);
    
    % Rcupration des donnes de Tb dans notre domaine.
    TbMSG = netcdf.getVar(ncid,0,[startlon-1 startlat-1 0],...
        [countlon countlat size(Temps,1)]);
    
    % Conversion des donnes d'aprs le facteur d'chelle et la
    % constante  ajouter obtenus par "ncdump" sous Unix.
    TbMSG = TbMSG*0.01+327.68;
    
    
    %%%%%%%%%%%%%%%%%%%%%%%%%%
    %     Initialisation
    %      des donnes 
    %      de sorties.
    %%%%%%%%%%%%%%%%%%%%%%%%%%
    
    if num_jour == 1;
       
        % Cration de la matrice d'intensit journalire.
        ij_intensity = zeros(100,100,nbjour);
        
        % Cration de la matrice d'information sur le temps.
        TempsMSG = zeros(1,nbjour);
        
    end
    
    
    %%%%%%%%%%%%%%%%%%%%%%%%%%
    %         Lissage
    %           et
    %     Interpolation
    %%%%%%%%%%%%%%%%%%%%%%%%%%
    
    TbMSG = double(TbMSG);
    m_TbMSG = zeros(100,100,size(Temps,1));
    TbLiss = zeros(size(TbMSG));
    
    for num_15min = 1 : size(Temps,1);
        
        TbLiss_15min = smooth(TbMSG(:,:,num_15min),'lowess');
        TbLiss_15min = reshape(TbLiss_15min,size(Longitudes,1),size(Latitudes,1));
        TbLiss(:,:,num_15min) = TbLiss_15min;
        
        xi = 1 : (size(TbMSG,1)-1)/99 : size(TbMSG,1);
        yi = (1 : (size(TbMSG,2)-1)/99 : size(TbMSG,2))';
        
        m_TbMSG(:,:,num_15min) = interp2(TbLiss(:,:,num_15min),xi,yi);
        
    end
    
%     %%% Visualisation des diffrences %%%
%     for i=1:96;
%     subplot(1,2,1)
%     imagesc(TbMSG(:,:,i));
%     subplot(1,2,2)
%     imagesc(m_TbMSG(:,:,i));
%     pause
%     end
    
    
    %%%%%%%%%%%%%%%%%%%%%%%%%%
    %       Labellisation
    %           des
    %          nuages
    %%%%%%%%%%%%%%%%%%%%%%%%%%
    
    DetectionNuage = bwlabeln(m_TbMSG<=Tb_SeuilSup);
    numax = max(DetectionNuage(:));
    
    %%%%%%%%%%%%%%%%%%%%%%%%%%
    % Eliminations des brefs
    %%%%%%%%%%%%%%%%%%%%%%%%%%
    
    for num_nuage = 1 : numax;
        
        % On cherche  quel quart d'heure le nuage apparait.
        num_15min = 1;
        while size(find(DetectionNuage(:,:,num_15min) == num_nuage), 1) == 0 && num_15min ~= size(Temps,1)-(Tps_SeuilInf-1);
            num_15min = num_15min + 1;
        end
        
        % On vrifie que le nuage est prsent, depuis le temps o il
        % apparait jusqu'a atteindre le seuil dfinit prcdemment.
        Elimination = 0;
        num_15minSup = 0;
        while num_15minSup ~= Tps_SeuilInf-1 && Elimination == 0;
            
            % Si parmi les quarts d'heure o le nuage doit tre prsent
            % n'est pas dtect, alors il ne satisfait pas le critre de
            % temps et n'est plus pris en compte.
            if size(find(DetectionNuage(:,:,num_15min+num_15minSup) == num_nuage), 1) == 0;
                Elimination = 1;
                DetectionNuage(DetectionNuage == num_nuage) = 0;
            end
            
            num_15minSup = num_15minSup + 1;
            
        end
        
    end
    
    %%%%%%%%%%%%%%%%%%%%%%%%%%
    %    Re-Labellisation
    %%%%%%%%%%%%%%%%%%%%%%%%%%
    
    DetectionNuage = bwlabeln(DetectionNuage);
    numax = max(DetectionNuage(:));
    
    
    %%%%%%%%%%%%%%%%%%%%%%%%%%
    %      Modle de nuages
    %            
    %       deux couches
    %%%%%%%%%%%%%%%%%%%%%%%%%%
    
    Tb2couches = zeros(size(m_TbMSG));
    
    %%%%%%%%%%%%%%%%%%%%%%%%%%
    %  Boucle sur les nuages
    %%%%%%%%%%%%%%%%%%%%%%%%%%
    
    for num_nuage = 1 : numax;
        
        ZoneNoyau = find(m_TbMSG <= Tb_LimNoyau & DetectionNuage==num_nuage);
        Tb2couches(ZoneNoyau) = mean(m_TbMSG(ZoneNoyau));
        
        ZoneExt = find(m_TbMSG > Tb_LimNoyau & m_TbMSG <= Tb_SeuilSup & DetectionNuage==num_nuage);
        Tb2couches(ZoneExt) = mean(m_TbMSG(ZoneExt));
        
    end
    
    
    %%%%%%%%%%%%%%%%%%%%%%%%%%
    %       Intensit
    %          en
    %      chaque point
    %%%%%%%%%%%%%%%%%%%%%%%%%%
    
    Tb2couches(Tb2couches==0)=NaN;
    Intensity = Tb_SeuilSup - Tb2couches;
    ij_intensity(:,:,num_jour) = nansum(Intensity,3);
    
    % Rcupration d'une variable de temps pour cette journe permettant de
    % retrouver la date.
    TempsMSG(num_jour) = Temps(1)/24 + datenum(1960,01,01);
    
end


% %%%% Images des intensits %%%%
% load coast;
% ij_intensity(ij_intensity==0) = NaN;
% for num_jour = 1 : nbjour;
%     set(gcf,'color','w','units','normalized','position',[0 0 1 1]);
%     image = imagesc(Longitudes,Latitudes,ij_intensity(:,:,num_jour)');
%     axis([lonmin lonmax latmin latmax])
%     set(image,'alphadata',~isnan(ij_intensity(:,:,num_jour)'));
%     hold on
%     set(gca,'ydir','normal');
%     colorbar;
%     coast = plot(long,lat,'k-');
%     xlabel('Longitudes');
%     ylabel('Latitudes');
%     title(['Intensit pour le ' datestr(TempsMSG(num_jour), 'dd mm yyyy')]);
%     ticklatlon;
%     grid on;
%     pause
%     delete(image, coast)
% end
% close all;
