function [tpota tva]=tpot(ta,pa,r)

%TPOT Calcul de la temperature potentielle et potentielle virtuelle

%+
%
% .. _tpot.m:
%
% =======
% tpot.m
% =======
%
% DESCRIPTION
% ===========
%
% Calcul de la temperature potentielle et potentielle virtuelle en degres Celsius
%
% Entrees : 
%
% ta
%    temperature en K ou degres C
% pa
%    pression en hPa ou Pa
% r
%    rapport de melange en g/kg ou kg/kg
%
% Sorties :
%
% tpota
%    temperature potentielle en degres C
% tva
%    temperature potentielle virtuelle en  degres C
%
% EXAMPLES
% ========
%
% voir :ref:`cal_hcl.m` pour exemple d'utilisation
%
% SEE ALSO
% ========
%
%
% TODO
% ====
%
% isolatin ou traduction
%
% EVOLUTIONS
% ==========
%
% $Id: tpot.m 325 2011-08-04 15:30:01Z pinsard $
%
% $URL$
%
%-

%test si pa est en Pa ou hPa et attribut a pstandard cette meme unite
ind_nan=find(~isnan(pa));
if pa(ind_nan(1)) < 2000
  pstandard = 1000;
else
  pstandard = 1000*100;
end

%test si r est en g/kg ou kg/kg
ind_nan=find(~isnan(r));
if r(ind_nan(1))>1
  r=r/1000;
end

%test si ta est en °C ou en K
% et calcule la temperature potentielle en °C
if ta(1) < 100  % il est peut probable d''avoir + de 100°C au niveau du sol
  tpota=((ta+273.15).*((pstandard./pa).^0.286))-273.15;   % (exposant=R/Cp)
else % ta déjà en K
  tpota=ta.*((pstandard./pa).^0.286)-273.15;   % (exposant=R/Cp)
end

% calcul la temperature potentielle virtuelle
tva=(tpota+273.15).*(1.+0.608*r)-273.15;
