function [uniquerandvalues] = uniquerand(N, minvalue, maxvalue)

%UNIQUERAND est une fonction permettant de trouver N valeurs aleatoires
%entieres et uniques reparties uniformement dans un intervalle donne.

%
%+
%
% =============
% uniquerand.m
% =============
%
% .. function:: uniquerand(N, minvalue, maxvalue)
%
% DESCRIPTION
% ===========
%
% - Donnees d'entrees :
%
%   * N : Nombres de valeurs aleatoires entieres et uniques que l'on
%     souhaite.
%   * minvalue : Borne inferieure de l'intervalle dans lequel on souhaite
%     avoir les valeurs.
%   * maxvalue : Borne superieure de l'intervalle dans lequel on souhaite
%     avoir les valeurs.
%
% - Donnees de sorties :
%
%   * uniquerandvalues : Vecteur lignes comportant les N valeurs aleatoires
%     entieres et uniques dans l'intervalle defini par minvalue et
%     maxvalue.
%
% Cette fonction permet de trouver N valeurs aleatoires entieres et uniques
% reparties uniformement dans un intervalle donne.
%
% EXAMPLES
% ========
%
% Voir la 'demo'.
%
% SEE ALSO
% ========
%
% TODO
% ====
%
% describe demo
%
% EVOLUTIONS
% ==========
%
% $Id$
%
% $URL$
%
% - jaclod 2011-07-28
%
%   * Creation.
%
%-

% Verification que l'intervalle comporte plus de nombres entiers que de
% valeurs demandees.
if N > fix(maxvalue)-ceil(minvalue)+1;
    error('Vous demandez plus de valeurs entieres uniques qu''il n''en existe dans l''intervalle donnee.');
end

% Creation d'un vecteur ligne de valeurs entieres aleatoires comprises
% entre les valeurs minimales et maximales.
uniquerandvalues = round(minvalue + (maxvalue - minvalue)*(rand(1,N)));

% Suppressions des eventuelles valeurs repetitives.
uniquerandvalues = unique(uniquerandvalues);

% S'il nous manque desormais des valeurs, on en reprend jusqu'a avoir
% definitivement N valeurs aleatoires entieres et uniques.
while size(uniquerandvalues,2) ~= N;

    % On cherche combien il manque de valeurs.
    n = N - size(uniquerandvalues,2);

    % On rajoute les n valeurs manquantes.
    uniquerandvalues = cat(2,uniquerandvalues,round(minvalue + (maxvalue - minvalue)*(rand(1,n))));

    % Suppressions des nouvelles eventuelles valeurs repetitives.
    uniquerandvalues = unique(uniquerandvalues);

end

clear('N','minvalue','maxvalue','n');

end

%!demo
%! [uniquerandvalues] = uniquerand(20, 10, 50);
