function [result] = visuTRMM(Annee, Mois, Jour, timestep, lonmin, lonmax, latmin, latmax)

%visuTRMM permet de faire une image des donnes prciptiations TRMM

%
%+
%
% ==========
% visuTRMM.m
% ==========
%
% .. function:: visuTRMM(Annee, Mois, Jour, timestep, lonmin, lonmax, latmin, latmax)
%
% DESCRIPTION
% ===========
%
% - Donnes d'entres :
%
%   * Annee (en caractres) : Anne (AAAA) du jour d'tude.
%   * Mois (en caractres) : Numro du mois (MM) du jour d'tude.
%   * Jour (en caractres) : Numro du jour d'tude
%   * timestep : Numro du pas de temps
%
%   :param lonmin: longitude min, W < 0
%   :units lonmin: deg
%   :type lonmin: double
%   :raise lonmin: required
%
%   :param lonmax: longitude max, W < 0
%   :units lonmax: deg
%   :type lonmax: double
%   :raise lonmax: required
%
%   :param latmin: latitude min, N > 0
%   :units latmin: deg
%   :type latmin: double
%   :raise latmin: required
%
%   :param latmax: latitude max, N > 0
%   :units latmax: deg
%   :type latmax: double
%   :raise latmax: required
%
% EXAMPLES
% ========
%
% Voir "demo".
%
% SEE ALSO
% ========
%
% :ref:`data_precipitation_microwave`
%
% :ref:`world_map`
%
% :func:`TRMMread`
%
% TODO
% ====
%
% make it work  now bad look of plot (all blue - 0 or less precipitation)
%
% color bar limit (to compare plots)
%
% externalize reading
%
% demo with simulation
%
% save figure
%
% hard coded title (should be long_name and units)
%
% EVOLUTIONS
% ==========
%
% $Id$
%
% $URL$
%
% - pinsard 2011-06-08T11:29:08Z loholt1.ipsl.polytechnique.fr (Linux)
%
%   * add box parameter
%
% - pinsard 2011-06-08T08:54:55Z loholt1.ipsl.polytechnique.fr (Linux)
%
%   * creation from visuMSG.m to check TRMMread.m
%
%-

result=-1;

% Si les informations sur la date n'ont pas t donnes, on les demande.
if exist('Annee','var')~=1;
    Annee = input('Anne (AAAA) : ', 's');
end

if exist('Mois','var')~=1;
    Mois = input('Mois (MM) : ', 's');
end

if exist('Jour','var')~=1;
    Jour = input('Jour (JJ) : ', 's');
end

if exist('timestep','var')~=1;
    timestep = input('Numro du pas de temps: ');
end

%%%%%%%%%%%%%%%%%%%%%%
% Lecture des donnes
%%%%%%%%%%%%%%%%%%%%%%

[data, Temps, Longitudes, Latitudes, Annee, Mois, Jour] = TRMMread(Annee, Mois, Jour, lonmin, lonmax, latmin, latmax);
%++ test si lecture ok
%
% reduce time domain
data=data(timestep,:,:);
Temps=Temps(timestep);
data=squeeze(data);
Temps=squeeze(Temps);

%%%%%%%%%
% Figure
%%%%%%%%%

% Ouverture d'une figure
figure();

% Modification des bornes pour les axes.
axis([lonmin lonmax latmin latmax]);

% Modification de la direction de l'axe Y (Latitudes).
set(gca,'Ydir','normal');

% Chargement des donnes cotires.
load('cmgco_traitdecote.mat','Xgco','Ygco');

% Ajout d'une barre de couleur
colorbar

hold on;

% Normalisation de la taille de la figure pour obtenir un carr.
set(gca, 'DataAspectRatio', [1 1 1]);

% Ajout d'un titre.
title(['Precipitation (mm/h) d''apres TRMM pour le ' datestr(Temps, 'dd mm yyyy a HH:MM')])

% Aperu des donnes
imagesc(Longitudes,Latitudes,data);

% Ajout des ctes.
coast=plot(Xgco,Ygco,'k.');

% Modification du format des valeurs sur les axes.
set(gca,'Xtick',lonmin:2:lonmax);
set(gca,'Ytick',latmin:2:latmax);
set(gca,'TickDir','in');
%++ pb glyph octave ticklatlon()

% Ajout de titres pour les axes.
xlabel('Longitudes','FontSize',15,'FontName','Times')
ylabel('Latitudes','FontSize',15,'FontName','Times')

% Modification de la police utilise.
set(gca,'FontSize',14,'FontName','Times');

% Ajout d'un cadre sur la figure.
set(gca,'Box','on');

result=0;

end

%!demo
%! clear all
%! close all
%! varamma_startup;
%! more off
%! Annee = '2006';
%! Mois = '08';
%! Jour = '01';
%! timestep = 1;
%! lonmin = -20;
%! lonmax = -10;
%! latmin = 10;
%! latmax = 20;
%! result=visuTRMM(Annee, Mois, Jour, timestep, lonmin, lonmax, latmin, latmax);
